@@ -1,4 +1,4 @@
-/* $Id: objpos.c,v 5.0 2001/04/07 20:01:00 dik Exp $
+/* $Id: objpos.c,v 5.1 2001/05/08 11:35:29 bertg Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -41,10 +41,6 @@
 
 char objpos_version[] = VERSION;
 
-#ifndef	lint
-static char sourceid[] =
-    "@(#)$Id: objpos.c,v 5.0 2001/04/07 20:01:00 dik Exp $";
-#endif
 
 void Object_position_set_clicks(object *obj, int cx, int cy)
 {
