@@ -1,4 +1,4 @@
-/* $Id: robotdef.c,v 5.18 2001/06/10 17:36:58 bertg Exp $
+/* $Id: robotdef.c,v 5.20.2.1 2001/11/04 19:01:13 dik Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -1928,7 +1928,8 @@ static void Robot_default_play_check_objects(int ind,
 	}
 
 	/* Ignore shots if shields already up - nothing else to do anyway */
-	if (BIT(shot->type, OBJ_SHOT) && BIT(pl->used, HAS_SHIELD)) {
+	if (BIT(shot->type, OBJ_SHOT|OBJ_CANNON_SHOT)
+	    && BIT(pl->used, HAS_SHIELD)) {
 	    continue;
 	}
 
@@ -1969,7 +1970,7 @@ static void Robot_default_play_check_objects(int ind,
 		    if (BIT(shot->status, RANDOM_ITEM)) {
 			imp = ROBOT_HANDY_ITEM;		/* It doesn't know what it is, so get it if it can */
 		    } else {
-			imp = Importance(ind, Obj[j]->info);
+			imp = Importance(ind, obj_list[j]->info);
 		    }
 		    if (imp > ROBOT_IGNORE_ITEM && imp >= *item_imp) {
 			*item_imp = imp;
@@ -2002,7 +2003,7 @@ static void Robot_default_play_check_objects(int ind,
 
 	/* Find nearest missile/mine */
 	if (BIT(shot->type, OBJ_TORPEDO|OBJ_SMART_SHOT|OBJ_ASTEROID
-			    |OBJ_HEAT_SHOT|OBJ_BALL)
+			    |OBJ_HEAT_SHOT|OBJ_BALL|OBJ_CANNON_SHOT)
 	    || (BIT(shot->type, OBJ_SHOT)
 		&& !BIT(World.rules->mode, TIMING)
 		&& shot->id != pl->id
@@ -2087,6 +2088,17 @@ static void Robot_default_play_check_objects(int ind,
 	    }
 	}
     }
+    // Convert *item_i from index in local obj_list[] to index in Obj[]
+    if (*item_i >= 0) {
+    for (j=0; (j < NumObjs) && (Obj[j]->id != obj_list[*item_i]->id); j++);
+    if (j >= NumObjs) {
+        *item_i = -1;  // Perhaps an error should be printed, too?
+    }
+    else {
+        *item_i = j;
+    }
+    }
+
 }
 
 static void Robot_default_play_check_lasers(int ind)
@@ -2176,7 +2188,7 @@ static void Robot_default_play(int ind)
     if (BIT(pl->have, HAS_CLOAKING_DEVICE) && pl->fuel.sum > pl->fuel.l2)
 	SET_BIT(pl->used, HAS_CLOAKING_DEVICE);
 
-    if (BIT(pl->have, ITEM_EMERGENCY_THRUST)
+    if (BIT(pl->have, HAS_EMERGENCY_THRUST)
 	&& !BIT(pl->used, HAS_EMERGENCY_THRUST)) {
 	Emergency_thrust(ind, 1);
     }
@@ -2495,7 +2507,7 @@ static void Robot_default_play(int ind)
 	Detect(ind, GetInd[pl->lock.pl_id])) {
 
 	ship = Players[GetInd[pl->lock.pl_id]];
-	shoot_time = (int)(pl->lock.distance / (pl->shot_speed + 1));
+	shoot_time = (int)(pl->lock.distance / (ShotsSpeed + 1));
 	dx = (long)(ship->pos.x + ship->vel.x * shoot_time);
 	dy = (long)(ship->pos.y + ship->vel.y * shoot_time);
 	/*-BA Also allow for our own momentum. */
